
API_LOGIN_URL = 'http://api.petkt.com/latest/user/login'
API_DEVICE_URL ='http://api.petkt.com/latest/discovery/device_roster'
API_FEEDERMINI_DEVICE_URL = 'http://api.petkt.com/latest/feedermini/owndevices'
API_FEEDERMINI_HISTORY_URL = 'http://api.petkt.com/latest/feedermini/dailyfeeds'